import{B as P,C as I,a1 as M,aC as p,aF as D,d as S,h as s,o as i,w as l,af as A,x as X,aB as Y,b1 as g,e as o,a as w,b as c,bm as H,c as f,u as y,s as N,V as T,k as z,M as F,t as n,bQ as L,n as B,bz as m,b5 as u,be as O,bS as $,bA as E,bR as R,bK as j}from"./index-BhOyEZK_.js";import{V as K,_ as Q}from"./NowPlayingBadge.vue_vue_type_style_index_0_lang-BBvJ2GE2.js";import{M as q}from"./MediaItemThumb-CbztwwtB.js";import{V as G}from"./VBtn-BOIOydWK.js";import{_ as J}from"./_plugin-vue_export-helper-DlAUqK2U.js";const U=I({disabled:Boolean,modelValue:{type:Boolean,default:null},...D()},"VHover"),W=P()({name:"VHover",props:U(),emits:{"update:modelValue":e=>!0},setup(e,b){let{slots:a}=b;const d=M(e,"modelValue"),{runOpenDelay:r,runCloseDelay:h}=p(e,v=>!e.disabled&&(d.value=v));return()=>a.default?.({isHovering:d.value,props:{onMouseenter:r,onMouseleave:h}})}}),Z={class:"thumb-container"},_={key:1,class:"play-button-overlay"},ee={key:0},te=S({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1},isAvailable:{type:Boolean,default:!0},isPlaying:{type:Boolean},parentItem:{default:void 0},disabled:{type:Boolean}},emits:["select"],setup(e,{emit:b}){const a=e,d=b,r=function(t){if(a.showCheckboxes)return;const C="clientX"in t?t.clientX:t.touches[0].clientX,k="clientY"in t?t.clientY:t.touches[0].clientY;R(a.item,C,k,a.parentItem)},h=function(t){if(a.showCheckboxes){d("select",a.item,!a.isSelected);return}$(a.item,t.clientX,t.clientY,a.parentItem)},v=function(t){a.showCheckboxes||j(a.item,t.clientX,t.clientY,a.parentItem)};return(t,C)=>{const k=E("hold");return i(),s(W,null,{default:l(({isHovering:V,props:x})=>[A((i(),s(X,Y(x,{class:{"on-hover":V,unavailable:!e.isAvailable},elevation:"0",disabled:e.disabled,onClick:h,onContextmenu:g(r,["right","prevent"])}),{default:l(()=>[e.showCheckboxes?(i(),s(H,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?t.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:l(()=>[c(K,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):o("",!0),w("div",Z,[c(q,{item:e.isAvailable?e.item:void 0},null,8,["item"]),e.isPlaying?(i(),s(Q,{key:0,"icon-style":"position: absolute; right: 5px; bottom: 5px","show-badge":!1})):o("",!0),(V||y(N).isTouchscreen)&&e.isAvailable&&e.item.is_playable?(i(),f("div",_,[c(G,{icon:"mdi-play",color:"white",fab:"",style:{opacity:"0.6","font-size":"20px"},onClick:g(v,["stop"])})])):o("",!0)]),c(T,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:l(()=>[c(z,null,{default:l(()=>[e.item.media_type==y(F).FOLDER?(i(),f("span",ee,[w("span",null,n(y(L)(e.item,t.$t)),1)])):(i(),f("span",{key:1,class:B({"is-playing":e.isPlaying})},n(e.item.name),3)),"version"in e.item&&e.item.version?(i(),f("span",{key:2,class:B({"is-playing":e.isPlaying})}," - "+n(e.item.version),3)):o("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(i(),s(m,{key:0,class:"line-clamp-1"},{default:l(()=>[u(n(y(O)(e.item.artists,1)),1)]),_:1})):o("",!0),"authors"in e.item&&e.item.authors?(i(),s(m,{key:1,class:"line-clamp-1"},{default:l(()=>[u(n(e.item.authors.join(" / ")),1)]),_:1})):"publisher"in e.item&&e.item.publisher?(i(),s(m,{key:2,class:"line-clamp-1"},{default:l(()=>[u(n(e.item.publisher),1)]),_:1})):"owner"in e.item&&e.item.owner?(i(),s(m,{key:3,class:"line-clamp-1"},{default:l(()=>[u(n(e.item.owner),1)]),_:1})):"provider_mappings"in e.item?o("",!0):(i(),s(m,{key:4,class:"line-clamp-1"},{default:l(()=>[u(n(t.$t(e.item.media_type)),1)]),_:1}))]),_:1})]),_:2},1040,["class","disabled"])),[[k,r]])]),_:1})}}}),oe=J(te,[["__scopeId","data-v-4a833c3f"]]);export{oe as P,W as V};
