import{d as R,m as y,h as s,o as t,N as p,u as o,bv as k,w as a,aR as V,c as m,n as C,b as r,a as b,e as c,z as h,t as v,aX as $,bt as x,F as B,g as M,bw as A,M as g,b5 as I}from"./index-BhOyEZK_.js";import{P as N}from"./PanelviewItemCompact-0b7dnUhV.js";import{V as T}from"./VToolbar-B9zhRGbf.js";import{V as u}from"./VBtn-BOIOydWK.js";import{V as z}from"./VAlert-BbF_x8Sn.js";import{_ as E}from"./_plugin-vue_export-helper-DlAUqK2U.js";const P=R({__name:"Carousel",setup(e){return y(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(d,l)=>{const w=p("swiper");return t(),s(w,{"slides-per-view":o(k)(d.$vuetify.display.width)+.5,"free-mode":!0,navigation:!1,mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:a(()=>[V(d.$slots,"default")]),_:3},8,["slides-per-view"])}}}),W={class:"mr-3"},D={key:0},F={class:"carousel-wrapper"},L=R({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean}},emits:["update:settings"],setup(e,{emit:d}){const l=d;return(w,n)=>{const f=p("swiper-slide");return t(),m("div",{class:C(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[r(T,{class:"header",color:"transparent"},{title:a(()=>[b("span",W,v(e.widgetRow.title),1),e.widgetRow.subtitle&&o($)("bp6")?(t(),s(x,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):c("",!0)]),append:a(()=>[e.editMode&&e.widgetRow.settings?(t(),m("div",D,[e.widgetRow.settings.position!==0?(t(),s(u,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:n[0]||(n[0]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):c("",!0),r(u,{icon:"mdi-chevron-down",onClick:n[1]||(n[1]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),r(u,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:n[2]||(n[2]=i=>l("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),s(h,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):c("",!0)]),_:1}),b("div",F,[e.widgetRow.items.length>0?(t(),s(P,{key:0},{default:a(()=>[(t(!0),m(B,null,M(e.widgetRow.items,i=>(t(),s(f,{key:i.uri},{default:a(()=>[r(N,{item:i,"permanent-overlay":![o(g).ALBUM,o(g).TRACK,o(g).RADIO].includes(i.media_type),"is-available":o(A)(i),disabled:e.editMode},null,8,["item","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),s(z,{key:1},{default:a(()=>[I(v(w.$t("no_content")),1)]),_:1}))])],2)}}}),q=E(L,[["__scopeId","data-v-b4fbe42a"]]);export{q as W};
